## 0.6.6 (2024-11-28)

### Fix

- it's var not vars
- add support for vars

### Refactor

- improve run command

[main ba07994] bump: version 0.6.5 → 0.6.6
 2 files changed, 12 insertions(+), 1 deletion(-)

